==> web-fw2_2_2.zip: web-fw2_2_2/j2src/weber/org/itscool/weber/tag/SelectTag.java <==
package org.itscool.weber.tag;

import javax.servlet.jsp.JspException;

import org.itscool.commons.util.TagUtil;
import org.itscool.weber.action.Globals;

/**
 * HTML&lt;select&gt;^O𐶐^OłB<BR>
 * multiple̎wɂĕI\ȃXgPĨv_Ej[
 * Ił܂B<BR>
 * <BR>
 *yz<BR>
 * size xɕ\ł\<BR>
 * name ̃tB[h̏lݒ肷ۂɎgBean̖Oiȗ\j<BR>
 * property Tu~bgɑM郊NGXgp[^iK{j<BR>
 * multiple ̒lI\ɂꍇtruew肷<BR>
 *          ftHgFfalse<BR>
 *
 * @author KANO
 * @since jdk1.4.1
 * @version 1.00A 2004/11/1
*/
public class SelectTag extends HtmlBodyTag {
	/** sIۃtO */
    protected String multiple;
    /** \tB[h̃TCY */
    protected String size;

    public String getMultiple() {
        return multiple;
    }

    public void setMultiple(String multiple) {
        this.multiple = multiple;
    }

    public String getSize() {
        return size;
    }

    public void setSize(String size) {
        this.size = size;
    }

    /**
     * select^OHTMLɏo܂B<br>
     * scopew肳ĂȂꍇ́ȀŃIuWFNg܂B
     * request, session, context̏
    */
    public int doStartTag() throws JspException {
        StringBuffer inputTag = new StringBuffer("<select ");
		if( htmlname != null && htmlname.length() > 0 ){
			inputTag.append( TagUtil.createAttribute("name", htmlname) );
		}else{
			inputTag.append( TagUtil.createAttribute("name", property) );
		}
        inputTag.append(TagUtil.createAttribute("multiple", multiple));
        inputTag.append(TagUtil.createAttribute("size", size));
        inputTag.append(TagUtil.createAttribute("style", style));
		inputTag.append(TagUtil.createBoolAttribute("readonly", readonly));
		inputTag.append(TagUtil.createBoolAttribute("disabled", disabled));
		inputTag.append(TagUtil.createBoolAttribute("class", csClass));
        inputTag.append(this.createJavaScriptTag());
        inputTag.append(" >");
        
        try{
            pageContext.getOut().print(inputTag.toString());
        }catch(Exception e){
            throw new JspException(e.getMessage());
        }
        
        //namenullłȂ΁AnamepropertyŎw肳ꂽ
        //IuWFNg̃vpeBNGXgp[^擾܂B
        //擾ꂽvpeB́ASELECT_TAG_NAMEASELECT_TAG_VALUE
        //̖OŎw肳ꂽNGXgp[^ɃZbgA
        //OptionTagselected𔻒肷ׂ̃p[^ƂĎgp܂
        if(name != null ){
            Object beanVal =
                TagUtil.findObject(pageContext, name, scope);
            if( beanVal != null ){
                try {
                	//vpeBZbg܂
                    pageContext.getRequest().setAttribute(
                        Globals.SELECT_TAG_NAME,
                        property);
                    //vpeBZbg܂
					pageContext.getRequest().setAttribute(
						Globals.SELECT_TAG_VALUE,
						beanVal);
                } catch (Exception e) {
                    throw new JspException(e.getMessage());
                }
            }
        }
        return EVAL_BODY_INCLUDE;
    }

    public int doEndTag() throws JspException {
        try {
            pageContext.getOut().print("</select>");
        } catch (Exception e) {
            throw new JspException(e.getMessage());
        }
        return SKIP_BODY;
    }

}

==> web-fw3_0_2.zip: web-fw3_0_2/j2src/weber/org/itscool/weber/tag/SelectTag.java <==
package org.itscool.weber.tag;

import javax.servlet.jsp.JspException;

import org.itscool.commons.util.JspTagUtil;
import org.itscool.weber.action.Globals;

/**
 * HTML&lt;select&gt;^O𐶐^OłB<BR>
 * multiple̎wɂĕI\ȃXgPĨv_Ej[
 * Ił܂B<BR>
 * <BR>
 *yz<BR>
 * size xɕ\ł\<BR>
 * name ̃tB[h̏lݒ肷ۂɎgBean̖Oiȗ\j<BR>
 * property Tu~bgɑM郊NGXgp[^iK{j<BR>
 * multiple ̒lI\ɂꍇtruew肷<BR>
 *          ftHgFfalse<BR>
 *
 * @author KANO
 * @since jdk1.4.1
 * @version 1.00A 2004/11/1
*/
public class SelectTag extends HtmlBodyTag {
	/** sIۃtO */
    protected String multiple;
    /** \tB[h̃TCY */
    protected String size;

    public String getMultiple() {
        return multiple;
    }

    public void setMultiple(String multiple) {
        this.multiple = multiple;
    }

    public String getSize() {
        return size;
    }

    public void setSize(String size) {
        this.size = size;
    }

    /**
     * select^OHTMLɏo܂B<br>
     * scopew肳ĂȂꍇ́ȀŃIuWFNg܂B
     * request, session, context̏
    */
    public int doStartTag() throws JspException {
        StringBuffer inputTag = new StringBuffer("<select ");
		if( htmlname != null && htmlname.length() > 0 ){
			inputTag.append( JspTagUtil.createAttribute("name", htmlname) );
		}else{
			inputTag.append( JspTagUtil.createAttribute("name", property) );
		}
        inputTag.append(JspTagUtil.createAttribute("multiple", multiple));
        inputTag.append(JspTagUtil.createAttribute("size", size));
        inputTag.append(JspTagUtil.createAttribute("style", style));
		inputTag.append(JspTagUtil.createBoolAttribute("readonly", readonly));
		inputTag.append(JspTagUtil.createBoolAttribute("disabled", disabled));
		inputTag.append(JspTagUtil.createBoolAttribute("class", csClass));
        inputTag.append(this.createJavaScriptTag());
        inputTag.append(" >");
        
        try{
            pageContext.getOut().print(inputTag.toString());
        }catch(Exception e){
            throw new JspException(e.getMessage());
        }
        
        //namenullłȂ΁AnamepropertyŎw肳ꂽ
        //IuWFNg̃vpeBNGXgp[^擾܂B
        //擾ꂽvpeB́ASELECT_TAG_NAMEASELECT_TAG_VALUE
        //̖OŎw肳ꂽNGXgp[^ɃZbgA
        //OptionTagselected𔻒肷ׂ̃p[^ƂĎgp܂
        if(name != null ){
            Object beanVal =
                JspTagUtil.findObject(pageContext, name, scope);
            if( beanVal != null ){
                try {
                	//vpeBZbg܂
                    pageContext.getRequest().setAttribute(
                        Globals.SELECT_TAG_NAME,
                        property);
                    //vpeBZbg܂
					pageContext.getRequest().setAttribute(
						Globals.SELECT_TAG_VALUE,
						beanVal);
                } catch (Exception e) {
                    throw new JspException(e.getMessage());
                }
            }
        }
        return EVAL_BODY_INCLUDE;
    }

    public int doEndTag() throws JspException {
        try {
            pageContext.getOut().print("</select>");
        } catch (Exception e) {
            throw new JspException(e.getMessage());
        }
        return SKIP_BODY;
    }

}
